###############################################################################
#        FULL BACKUP UYILITY FOR ENIGMA2/, SUPPORTS THE MODELS Mixos mini     #
#                   MAKES A FULLBACK-UP READY FOR FLASHING.                   #
#                                                                             #
#                    Based on Pedro_Newbie Backupsuite                        #
###############################################################################
#
#!/bin/sh
export LANG=$2
VERSION="Version 1.0 - 09-12-2012"

START=$(date +%s)

##DECLARATION OF VARIABLES

MEDIA=$1
HARDDISK=$3
DATE=`date +%Y%m%d_%H%M`
IMAGEVERSION=`date +%Y%m%d`
MKFS=/usr/sbin/mkfs.jffs2
NANDDUMP=/usr/sbin/nanddump
WORKDIR=$MEDIA/bi
TARGET="XX"
MESSAGE="python /usr/lib/enigma2/python/Plugins/Extensions/BackupSuite-HDD/message.py"
# ABOVE IS THE PATH FOR THE (ERROR-)MESSAGES

## TESTING THE MIXOS MODELS
if [ -f /proc/stb/info/boxtype ] ; then
	MODEL=$( cat /proc/stb/info/boxtype )
	if grep ebox /proc/stb/info/boxtype > /dev/null ; then
		TYPE=EBOX
		SHOWNAME="Mixos mini"
		MAINDEST=$MEDIA/ebox/7403
		EXTRA=$MEDIA/fullbackup_ebox5100/$DATE
	else
		$MESSAGE "message01" $LANG 					# No supported receiver found!
		exit 0
	fi
fi
## START TO SHOW SOME INFORMATION ABOUT MAKE, MODEL AND FILESYSTEM
echo "$SHOWNAME" | tr  a-z A-Z						# Shows the receiver brand and model in UPPERCASE
$MESSAGE "message02" $LANG 							# BACK-UP TOOL FOR MAKING A COMPLETE BACK-UP 
echo "$VERSION"
echo "MixOS-Support"
echo " "

$MESSAGE "message04" $LANG						# Please be patient, ... will now be made, this will take between 2 and 4 minutes.

echo " "

## TESTING IF ALL THE TOOLS FOR THE BUILDING PROCESS ARE PRESENT
if [ ! -f $MKFS ] ; then
	echo $MKFS; $MESSAGE "message05" $LANG 			# MKFS.UBIFS or MKFS.JFFS2 not found.
	exit 0
fi
if [ ! -f $NANDDUMP ] ; then
	echo $NANDDUMP ;$MESSAGE "message05" $LANG 		# Nanddump not found.
	exit 0
fi

## PREPARING THE BUILDING ENVIRONMENT
rm -rf $WORKDIR										# GETTING RID OF THE OLD REMAINS IF ANY
mkdir -p $WORKDIR									# MAKING THE WORKING FOLDER WHERE EVERYTHING HAPPENS
mkdir -p /tmp/bi/root
sync
mount --bind / /tmp/bi/root

## START THE REAL BACK-UP PROCESS
$MESSAGE "message06" $LANG 						#Create: root.jffs2
$MKFS --root=/tmp/bi/root --faketime --output=$WORKDIR/root.jffs2 --eraseblock=0x20000 -n -l
chmod 644 $WORKDIR/root.jffs2

$MESSAGE "message07" $LANG 							# Create: kerneldump
nanddump -a -f $WORKDIR/vmlinux.gz /dev/mtd1

echo " "
$MESSAGE "message08" $LANG 							# Almost there... Now building the USB-Image!

## HANDLING THE ebox SERIES
if [ $TYPE = "EBOX" ] ; then
	rm -rf $MAINDEST
	mkdir -p $MAINDEST
	mkdir -p $EXTRA
	mv $WORKDIR/root.jffs2 $MAINDEST/root_cfe_auto.bin
	mv $WORKDIR/vmlinux.gz $MAINDEST/kernel_cfe_auto.bin
	echo MixOS F5 - $IMAGEVERSION > $MAINDEST/imageversion
	cp -r $MAINDEST $EXTRA 							#copy the made back-up to images
	if [ -f $MAINDEST/root_cfe_auto.bin -a -f $MAINDEST/kernel_cfe_auto.bin -a -f $MAINDEST/imageversion ] ; then
		echo " "
		echo " "
		$MESSAGE "message10" $LANG ; echo $MAINDEST # USB Image created in: 
		$MESSAGE "message11" $LANG ; echo $EXTRA	# and there is made an extra copy in:
		echo " "
		$MESSAGE "message14" $LANG				# Please check te manual of the receiver on how to restore the image.
	else
		$MESSAGE "message15" $LANG					# Image creation FAILED!
	fi
fi

if  [ $HARDDISK = 1 ]; then							# looking for a valid usb-stick
	for candidate in  /media/usb /media/sdb1 /media/sdc1 /media/sdd1 /media/sde1 /media/mmc1 
	do
		if [ -f ${candidate}/*backupstick* ]
		then
		TARGET=${candidate}
		fi    
	done
	if [ $TARGET != "XX" ] ; then
		echo " "
		$MESSAGE "message17" $LANG 					# Valid USB-flashdrive detected, making an extra copy
		echo " "
		$MESSAGE "message18" $LANG 					# This only takes about 20 seconds.....
		SIZE_1="$(df -h $TARGET | grep $TARGET | awk {'print $4'})"
		SIZE_2="$(df -h $TARGET | grep $TARGET | awk {'print $2'})"
		echo "Extra Back-up -> $TARGET ($SIZE_2)"
		echo "Free ----------> $SIZE_1"
		#echo " "
		if [ $TYPE = "EBOX" ] ; then
			rm -rf $TARGET/ebox/7403			# New bootloader/image
			mkdir -p $TARGET/ebox/7403
			cp -r $MAINDEST $TARGET
		fi
    sync
	$MESSAGE "message19" $LANG						# Backup finished and copied to your USB-flashdrive
	fi
fi
umount /tmp/bi/root
rmdir /tmp/bi/root
rmdir /tmp/bi
rm -rf $WORKDIR
sleep 5
END=$(date +%s)
DIFF=$(( $END - $START ))
MINUTES=$(( $DIFF/60 ))
SECONDS=$(( $DIFF-(( 60*$MINUTES ))))
if [ $SECONDS -le  9 ] ; then 
	SECONDS="0$SECONDS"
fi
$MESSAGE "message24" $LANG ; echo "$MINUTES:$SECONDS"
exit 